%define anolis_release 3

Name:           btrfs-progs
Summary:        An userspace programs named btrfs
Version:        6.1.2
Release:        %{anolis_release}%{?dist}

License:        GPLv2
URL:            https://btrfs.wiki.kernel.org/index.php/Main_Page
Source0:        https://mirrors.edge.kernel.org/pub/linux/kernel/people/kdave/%{name}/%{name}-v%{version}.tar.xz
Source1:        https://mirrors.edge.kernel.org/pub/linux/kernel/people/kdave/%{name}/%{name}-v%{version}.tar.sign
Source2:        gpgkey-F2B41200C54EFB30380C1756C565D5F9D76D583B.gpg

BuildRequires:  gnupg2 e2fsprogs-devel libacl-devel, lzo-devel systemd
BuildRequires:  gcc, autoconf, automake, make
BuildRequires:  pkgconfig(blkid) pkgconfig(uuid) pkgconfig(zlib) pkgconfig(libgcrypt) >= 1.8.0 pkgconfig(libudev) pkgconfig(libzstd) >= 1.0.0
BuildRequires:  python3-devel >= 3.4 python3-sphinx python3-setuptools python3-rpm-macros

%description
Btrfs is a modern copy on write (COW) filesystem for Linux
aimed at implementing advanced features while also focusing
on fault tolerance, repair and easy administration.

%package -n libbtrfs
Summary:        btrfs filesystem-specific runtime libraries
License:        GPLv2
Provides:       deprecated()
Conflicts:      %{name} < 4.20.2

%description -n libbtrfs
libbtrfs includes the main library which is used by btrfs filesystem-specific programs.

%package -n libbtrfsutil
Summary:        btrfs filesystem-specific runtime utility libraries
License:        LGPLv2+
Conflicts:      %{name}-devel < 4.20.2

%description -n libbtrfsutil
libbtrfsutil contains an alternative utility library used by btrfs
filesystem-specific programs.

%package devel
Summary:        btrfs filesystem-specific libraries and headers
License:        GPLv2 and LGPLv2+
Requires:       %{name} = %{EVR}
Requires:       libbtrfsutil = %{EVR}
Requires:       libbtrfs = %{EVR}

%description devel
This devel package provides the libraries and header files which is used to
develop btrfs filesystem-specific programs. It includes development files
for two libraries: libbtrfs (GPLv2) and libbtrfsutil (LGPLv2+). Please install
btrfs-progs-devel if you want to develop the btrfs filesystem-specific programs.

%package -n python3-btrfsutil
Summary:        Python 3 bindings for libbtrfsutil
License:        LGPLv2+
Requires:       libbtrfsutil = %{EVR}
%{?python_provide:%python_provide python3-btrfsutil}

%description -n python3-btrfsutil
python3-btrfsutil provides Python3 bindings to the libbtrfsutil library used
for btrfs filesystem-specific programs in Python. Please install python3-btrfsutil
if you want to use or develop btrfs filesystem-specific programs in Python.

%prep
xzcat '%{SOURCE0}' | %{gpgverify} --keyring='%{SOURCE2}' \
	--signature='%{SOURCE1}' --data=-
%autosetup -p1 -n %{name}-v%{version}

%build
./autogen.sh
%configure CFLAGS="%{optflags} -fno-strict-aliasing" \
	--disable-python \
	--with-crypto=libgcrypt
%make_build

pushd libbtrfsutil/python
%py3_build
popd

%install
%make_install mandir=%{_mandir} \
	bindir=%{_sbindir} \
	libdir=%{_libdir} \
	incdir=%{_includedir}

%{__install} -D -p -m 0644 btrfs-completion %{buildroot}%{_datadir}/bash-completion/completions/btrfs
%{__rm} -v %{buildroot}%{_libdir}/*.a

pushd libbtrfsutil/python
%py3_install
popd

%generate_compatibility_deps

%files
%dir %{abidir}
%license COPYING
%{_sbindir}/btrfs-convert
%{_sbindir}/btrfs-map-logical
%{_sbindir}/btrfs-find-root
%{_sbindir}/btrfsck
%{_sbindir}/fsck.btrfs
%{_sbindir}/btrfs-select-super
%{_sbindir}/btrfstune
%{_sbindir}/btrfs
%{_sbindir}/mkfs.btrfs
%{_sbindir}/btrfs-image
%{abidir}/btrfs-convert-option.list
%{abidir}/btrfs-find-root-option.list
%{abidir}/btrfs-image-option.list
%{abidir}/btrfs-option.list
%{_udevrulesdir}/64-btrfs-dm.rules
%{_udevrulesdir}/64-btrfs-zoned.rules
%{_datadir}/bash-completion/completions/btrfs
%{abidir}/btrfstune-option.list
%{abidir}/btrfsutil.cpython-%{python3_version_nodots}-%{_arch}-linux-gnu.dump
%{abidir}/fsck.btrfs-option.list
%{abidir}/mkfs.btrfs-option.list
%{_mandir}/man5/*
%{_mandir}/man8/*

%files -n libbtrfs
%license COPYING
%{_libdir}/libbtrfs.so.0*
%{abidir}/libbtrfs.dump

%files -n libbtrfsutil
%license libbtrfsutil/COPYING
%{_libdir}/libbtrfsutil.so.1*
%{abidir}/libbtrfsutil.dump

%files devel
%{_libdir}/libbtrfsutil.so
%{_libdir}/pkgconfig/libbtrfsutil.pc
%{_libdir}/libbtrfs.so
%{_includedir}/*

%files -n python3-btrfsutil
%license libbtrfsutil/COPYING
%{python3_sitearch}/btrfsutil-*.egg-info/
%{python3_sitearch}/btrfsutil.*.so

%changelog
* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 6.1.2-3
- Rebuild with python3.11
- Fix build error

* Tue Apr 11 2023 Heng Qi <hengqi@linux.alibaba.com> - 6.1.2.-2
- Refactor the spec file

* Fri Jan 13 2023 Ziyang Zhang <ZiyangZhang@linux.alibaba.com> - 6.1.2-1
- remove ascii and xmlto dependency since they are unnecessary now
- add sphinx dependency for building docs
- use libgcrypt for providing hash implementations

* Thu Nov 03 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.16.2-2
- optimise spec file

* Mon Apr 11 2022 Zhongling He <zhonglingh@linux.alibaba.com> 5.16.2-1
- Init package from upstream v5.16.2
